@@ -13,9 +13,9 @@ class Vectorizer:
         self.words = []
         self.vectors = []
 
-    def bert(self, sentences):
+    def bert(self, sentences, pretrained_weights='distilbert-base-uncased'):
         self.sentences = sentences
-        model_class, tokenizer_class, pretrained_weights = (ppb.DistilBertModel, ppb.DistilBertTokenizer, 'distilbert-base-uncased')
+        model_class, tokenizer_class, pretrained_weights = (ppb.DistilBertModel, ppb.DistilBertTokenizer, pretrained_weights)
         tokenizer = tokenizer_class.from_pretrained(pretrained_weights)
         model = model_class.from_pretrained(pretrained_weights)
         encoder = lambda x: tokenizer.encode(x, add_special_tokens=True)
